{ config, pkgs, ... }: {

  boot = {
    kernelPackages = pkgs.linuxPackages_latest;
    initrd.availableKernelModules =
      [ "nvme" "xhci_pci" "ahci" "usbhid" "usb_storage" "sd_mod" "sdhci_acpi" ];
    initrd.kernelModules = [ "dm-snapshot" ];
    kernelModules = [ "kvm-amd" ];
    extraModulePackages = [ ];
    loader.systemd-boot.enable = true;
    loader.efi.canTouchEfiVariables = false;
  };

  services.btrfs.autoScrub.enable = true;
  fileSystems."/data" = {
    device = "/dev/disk/by-uuid/78e8e5b5-9068-4381-8e85-b4297607f9ea";
    fsType = "btrfs";
    options = [
      "autodefrag"
      "space_cache"
      "inode_cache"
      "noatime"
      "nodiratime"
      "compress=zstd"
    ];
  };

  fileSystems."/" = {
    device = "/dev/disk/by-uuid/28afab71-ff3d-4f1a-b7e4-2129572706dd";
    fsType = "btrfs";
  };

  fileSystems."/boot" = {
    device = "/dev/disk/by-uuid/5BFB-9E6B";
    fsType = "vfat";
  };

  swapDevices = [ ];

  nix.settings = {
    max-jobs = 8;
    cores = 0; # auto
  };

  zramSwap = {
    enable = true;
    algorithm = "zstd";
    memoryPercent = 50;
  };
}
