{ config, pkgs, inputs, lib, system, nixpkgs-nixos-unstable-and-unfree, ... }: {

  networking.hostName = "yoga";

  imports = [ ./hardware-configuration.nix ../../boot.nix ../../git ];

  boot.kernelPackages = pkgs.linuxPackages_latest;

  hardware.trackpoint.enable = true;
  services.hardware.bolt.enable = true;

  services.fprintd = { enable = true; };

  home-manager.users.cyryl = { lib, ... }: {
    home.packages = with pkgs; [ firefox vim gnome3.gedit git ];
  };

  networking.networkmanager.enable = true;

  time.timeZone = "Europe/London";

  i18n.defaultLocale = "en_GB.utf8";

  services.xserver.enable = true;

  services.xserver.displayManager.gdm.enable = true;
  services.xserver.desktopManager.gnome.enable = true;

  services.xserver = {
    layout = "pl";
    xkbVariant = "";
  };

  console.keyMap = "pl2";

  services.printing.enable = true;

  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };
  services.xserver.libinput.enable = true;

  users.users.cyryl = {
    isNormalUser = true;
    description = "cyryl";
    extraGroups = [ "networkmanager" "wheel" ];
    packages = with pkgs;
      [

      ];
  };

  services.fwupd.enable = true;

  services.xserver.displayManager.autoLogin.enable = true;
  services.xserver.displayManager.autoLogin.user = "cyryl";

  # Workaround for GNOME autologin: https://github.com/NixOS/nixpkgs/issues/103746#issuecomment-945091229
  systemd.services."getty@tty1".enable = false;
  systemd.services."autovt@tty1".enable = false;

  nix = {
    settings.auto-optimise-store = true;
    gc.automatic = true;
    optimise.automatic = true;
    package = pkgs.nixUnstable;
    extraOptions = ''
      experimental-features = nix-command flakes
    '';
  };

  system = { stateVersion = "22.05"; };

}
