{ config, pkgs, lib, inputs, nixpkgs-nixos-unstable-and-unfree, ... }:
let
  stateVersion = "22.05";
  username = "cyryl";
in {
  imports = [
    ./common-hardware.nix
    ./common-services.nix
    ./security.nix
    ./syncthing.nix
  ];

  security.allowUserNamespaces = true;

  environment.enableDebugInfo = true;

  environment.systemPackages = with pkgs; [
    ccache
    curl
    dnsutils
    fd
    git
    gnupg
    home-manager
    htop
    pciutils
    powertop
    tmux
    usbutils
    wget
    nixpkgs-nixos-unstable-and-unfree.veracrypt
  ];

  i18n.defaultLocale = "en_GB.UTF-8";

  users.users."${username}" = {
    isNormalUser = true;
    extraGroups = [
      "adbusers"
      "dialout"
      "docker"
      "libvirtd"
      "lp"
      "networkmanager"
      "scanner"
      "vboxusers"
      "video"
      "wheel"
      "wireshark"
    ];
    shell = pkgs.zsh;
  };

  networking.nameservers =
    [ "91.239.100.100" "89.233.43.71" "1.1.1.1" "8.8.8.8" ];

  networking.hosts = { "10.11.99.1" = [ "remarkable" ]; };

  programs.light.enable = true;
  programs.adb.enable = true;
  programs.wireshark.enable = true;

  virtualisation.docker = {
    enable = true;
    autoPrune.enable = true;
    daemon.settings = {
      "insecure-registries" = [ "vpsfree1.raptor-carp.ts.net:5000" ];
    };
  };

  fonts.fontconfig = {
    enable = true;
    defaultFonts.monospace = [ "Berkeley Mono" ];
  };

  fonts.fonts = with pkgs;
    [
      (runCommand "berkeley-fonts" { } ''
        mkdir -vp "$out/share/fonts/opentype"
        mkdir -vp "$out/share/fonts/truetype"
        ${pkgs.unzip}/bin/unzip ${
          ./fonts.zip
        } \*.otf -d $out/share/fonts/opentype
        ${pkgs.unzip}/bin/unzip ${
          ./fonts.zip
        } \*.ttf -d $out/share/fonts/truetype

      '')
    ];

  nix = {
    settings.auto-optimise-store = true;
    gc.automatic = true;
    optimise.automatic = true;
    package = pkgs.nixUnstable;
    extraOptions = ''
      experimental-features = nix-command flakes
    '';
  };

  system = { inherit stateVersion; };
}
