{ config, pkgs, ... }: {
  imports = [ ./autorandr.nix ./openweathermap-secrets.nix ];
  environment.systemPackages = with pkgs; [ dconf ];
  programs.dconf.enable = true;

  security.sudo.extraRules = [
    {
      users = [ "cyryl" ];
      commands = [{
        command = "${pkgs.i3}/bin/i3-msg";
        options = [ "NOPASSWD" ];
      }];
    }
    {
      users = [ "cyryl" ];
      commands = [{
        command = "${pkgs.intel-gpu-tools}/bin/intel_gpu_top";
        options = [ "NOPASSWD" ];
      }];
    }
  ];

  xdg.portal = {
    enable = true;
    extraPortals = with pkgs; [ xdg-desktop-portal-gtk xdg-desktop-portal-kde ];
  };

  services = {
    physlock = {
      enable = true;
      allowAnyUser = true;
    };

    dbus = { packages = with pkgs; [ gnome2.GConf dconf ]; };

    fractalart.enable = true;
    colord.enable = true;
    xserver.windowManager.i3.enable = true;
    xserver.displayManager.sddm = {
      enable = true;
      enableHidpi = true;
    };
  };
  home-manager.users.cyryl = { ... }: {
    imports = [ ./home.nix ];
    home.packages = with pkgs; [ ];
  };
}
