{ config, pkgs, inputs, ... }:
let
  inherit (inputs.nixpkgs-nixos-unstable.legacyPackages."x86_64-linux")
    tailscale;

in {
  environment.systemPackages = [ tailscale ];
  services.tailscale = {
    enable = true;
    package = tailscale;
  };

  networking.firewall = {
    trustedInterfaces = [ "tailscale0" ];
    allowedUDPPorts = [ config.services.tailscale.port ];
  };
  sops.secrets."tailscale-key-${config.networking.hostName}" = {
    sopsFile = ./keys.sops.yaml;
  };
  systemd.services.tailscale-auth = {
    description = "Auth with tailscale";

    after = [ "network-pre.target" "tailscale.service" ];
    wants = [ "network-pre.target" "tailscale.service" ];
    wantedBy = [ "multi-user.target" ];

    serviceConfig.Type = "oneshot";

    script = ''
      sleep 2

      status="$(${tailscale}/bin/tailscale status -json | ${pkgs.jq}/bin/jq -r .BackendState)"
      if [ $status = "Running" ]; then # if so, then do nothing
        exit 0
      fi

      ${tailscale}/bin/tailscale up -authkey `cat /run/secrets/tailscale-key-${config.networking.hostName}` 
    '';
  };
}
